# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails from dynamically allocated email addresses. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.   ## Resources - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://www.mailslurp.com/docs/) - [Examples](https://github.com/mailslurp/examples) repository   # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.email_controller_api import EmailControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestEmailControllerApi(unittest.TestCase):
    """EmailControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.email_controller_api.EmailControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_all_emails(self):
        """Test case for delete_all_emails

        Delete all emails  # noqa: E501
        """
        pass

    def test_delete_email(self):
        """Test case for delete_email

        Delete an email  # noqa: E501
        """
        pass

    def test_download_attachment(self):
        """Test case for download_attachment

        Get email attachment bytes. If you have trouble with byte responses try the `downloadAttachmentBase64` response endpoints.  # noqa: E501
        """
        pass

    def test_download_attachment_base64(self):
        """Test case for download_attachment_base64

        Get email attachment as base64 encoded string (alternative to binary responses)  # noqa: E501
        """
        pass

    def test_forward_email(self):
        """Test case for forward_email

        Forward email  # noqa: E501
        """
        pass

    def test_get_attachment_meta_data(self):
        """Test case for get_attachment_meta_data

        Get email attachment metadata  # noqa: E501
        """
        pass

    def test_get_attachments(self):
        """Test case for get_attachments

        Get all email attachment metadata  # noqa: E501
        """
        pass

    def test_get_email(self):
        """Test case for get_email

        Get email content  # noqa: E501
        """
        pass

    def test_get_email_content_match(self):
        """Test case for get_email_content_match

        Get email content regex pattern match results. Runs regex against email body and returns match groups.  # noqa: E501
        """
        pass

    def test_get_email_html(self):
        """Test case for get_email_html

        Get email content as HTML  # noqa: E501
        """
        pass

    def test_get_email_html_query(self):
        """Test case for get_email_html_query

        Parse and return text from an email, stripping HTML and decoding encoded characters  # noqa: E501
        """
        pass

    def test_get_email_text_lines(self):
        """Test case for get_email_text_lines

        Parse and return text from an email, stripping HTML and decoding encoded characters  # noqa: E501
        """
        pass

    def test_get_emails_paginated(self):
        """Test case for get_emails_paginated

        Get all emails  # noqa: E501
        """
        pass

    def test_get_raw_email_contents(self):
        """Test case for get_raw_email_contents

        Get raw email string  # noqa: E501
        """
        pass

    def test_get_raw_email_json(self):
        """Test case for get_raw_email_json

        Get raw email in JSON  # noqa: E501
        """
        pass

    def test_get_unread_email_count(self):
        """Test case for get_unread_email_count

        Get unread email count  # noqa: E501
        """
        pass

    def test_reply_to_email(self):
        """Test case for reply_to_email

        Reply to an email  # noqa: E501
        """
        pass

    def test_validate_email(self):
        """Test case for validate_email

        Validate email  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
